import { SubmitButton } from "@/components/simulation/common/submit-button";
import { useTranslations } from "next-intl";
import Image from "next/image";
import { redirect } from "next/navigation";
import { Suspense } from "react";

// Server action to handle form submission - optimized for faster redirection
async function handleStart() {
	"use server";
	// Use a direct redirect without any processing
	redirect("/simulation-program/structure-type");
}

// Skeleton component for the simulation program page
function SimulationProgramSkeleton() {
	return (
		<div className="h-screen w-full start-bg">
			<div
				className="flex flex-col items-center justify-evenly h-full"
				style={{ fontFamily: "var(--font-gedinar)" }}
			>
				{/* Page title skeleton */}
				<div className="h-24 w-[600px] bg-gray-200 rounded-md animate-pulse"></div>

				{/* Start button skeleton */}
				<div className="h-16 w-40 bg-gray-200 rounded-full animate-pulse"></div>

				{/* Pool image skeleton */}
				<div className="h-[250px] w-[250px] bg-gray-200 rounded-md animate-pulse"></div>
			</div>
		</div>
	);
}

export default function SwimmingPoolPage() {
	const t = useTranslations();

	return (
		<Suspense fallback={<SimulationProgramSkeleton />}>
			<div className="h-screen w-full start-bg">
				<div
					className="flex flex-col items-center justify-evenly h-full"
					style={{ fontFamily: "var(--font-gedinar)" }}
				>
					{/* Page title */}
					<h1 className="text-8xl text-[#1e1e1e] max-w-[600px] text-center font-medium opacity-60">
						{t("Swimming pool construction service")}
					</h1>

					{/* Start form */}
					<form action={handleStart}>
						<SubmitButton text={t("Start")} />
					</form>

					{/* Pool image */}
					<Image
						src="/swimming-pool/pool-shape-1.png"
						alt={t("Swimming pool illustration")}
						width={250}
						height={250}
						style={{ objectFit: "contain" }}
					/>
				</div>
			</div>
		</Suspense>
	);
}
